body {
    margin: 0;
    padding: 0;
}
* {
    margin: 0;
    padding: 0;
}
h1 {
    font-size: 1.3em;
    border-bottom: 1px solid #808080;
    background-color: #606060;
    color: white;
}
ul.log, 
ul.log li {
    margin: 0;
    padding: 0;
    list-style-type: none;
}
ul.log li {
    line-height: 1.2em;
    padding: 2px 0;
    border-top: 1px solid #e0e0e0;
}

.iframe-container iframe {
    height: 50%;
    width: 100%;
}

#recentlog-iframe-container iframe {
    height: 30%;
    width: 100%;
}
